@@ -1,6 +1,7 @@
 import os
 import signal
 import sys
+import sysconfig
 import threading
 import time
 import traceback
@@ -8,6 +9,7 @@ import traceback
 from . import ipc
 from .compat import get_py_path
 from .compat import interrupt_main
+from .compat import get_site_packages
 from .interfaces import IReloaderProxy
 from .utils import resolve_spec
 
@@ -15,6 +17,7 @@ from .utils import resolve_spec
 class WatchSysModules(threading.Thread):
     """ Poll ``sys.modules`` for imported modules."""
     poll_interval = 1
+    ignore_system_paths = True
 
     def __init__(self, callback):
         super(WatchSysModules, self).__init__()
@@ -22,6 +25,7 @@ class WatchSysModules(threading.Thread):
         self.callback = callback
         self.lock = threading.Lock()
         self.stopped = False
+        self.system_paths = get_system_paths()
 
     def run(self):
         while not self.stopped:
@@ -40,7 +44,7 @@ class WatchSysModules(threading.Thread):
                     self.paths.add(path)
                     new_paths.append(path)
         if new_paths:
-            self.callback(new_paths)
+            self.watch_paths(new_paths)
 
     def search_traceback(self, tb):
         """ Inspect a traceback for new paths to add to our path set."""
@@ -52,7 +56,36 @@ class WatchSysModules(threading.Thread):
                     self.paths.add(path)
                     new_paths.append(path)
         if new_paths:
-            self.callback(new_paths)
+            self.watch_paths(new_paths)
+
+    def watch_paths(self, paths):
+        if self.ignore_system_paths:
+            paths = [
+                path for path in paths
+                if not self.in_system_paths(path)
+            ]
+        if paths:
+            self.callback(paths)
+
+    def in_system_paths(self, path):
+        for prefix in self.system_paths:
+            if path.startswith(prefix):
+                return True
+        return False
+
+
+def get_system_paths():
+    paths = get_site_packages()
+    for name in {
+        'stdlib',
+        'platstdlib',
+        'platlib',
+        'purelib',
+    }:
+        path = sysconfig.get_path(name)
+        if path is not None:
+            paths.append(path)
+    return paths
 
 
 def expand_source_paths(paths):
@@ -136,6 +169,8 @@ class Worker(object):
         self._child_pipe.close()
 
     def is_alive(self):
+        if self.exitcode is not None:
+            return False
         if self.process:
             return self.process.poll() is None
         return False
@@ -145,8 +180,7 @@ class Worker(object):
         self.process.terminate()
 
     def join(self):
-        self.process.wait()
-        self.exitcode = self.process.returncode
+        self.exitcode = self.process.wait()
 
         if self.stdin_termios:
             ipc.restore_termios(sys.stdin.fileno(), self.stdin_termios)
